@@ -1,21 +1,22 @@
 #![forbid(unsafe_code)]
-#![warn(clippy::needless_pass_by_value)]
+#![warn(clippy::pedantic)]
+#![allow(clippy::module_name_repetitions)]
 
 #[cfg(not(feature = "fuzzer"))]
 mod ast;
 #[cfg(feature = "fuzzer")]
 pub mod ast;
 pub mod errors;
+mod format;
 mod regex;
-mod utils;
 
+use anyhow::Result;
 use ast::to_ast;
-use errors::ParseError;
+use format::format;
 #[cfg(not(feature = "fuzzer"))]
-use regex::to_regex;
+use regex::ast_to_regex;
 #[cfg(feature = "fuzzer")]
-pub use regex::to_regex;
-use utils::format_line_comments;
+pub use regex::ast_to_regex::ast_to_regex;
 
 /**
 Compiles Melody source code to a regular expression.
@@ -35,12 +36,12 @@ let output = compiler(source);
 assert_eq!(output.unwrap(), "A{1,5}");
 ```
 */
-pub fn compiler(source: &str) -> Result<String, ParseError> {
-    let formatted_source = format_line_comments(source);
+pub fn compiler(source: &str) -> Result<String> {
+    let formatted_source = format(source);
 
-    let ast = to_ast(formatted_source.as_str())?;
+    let ast = to_ast(&formatted_source)?;
 
-    let output = to_regex(&ast);
+    let output = ast_to_regex(&ast);
 
     Ok(output)
 }
